@@ -7,18 +7,15 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package PerlIO::via::Timeout;
-{
-  $PerlIO::via::Timeout::VERSION = '0.29';
-}
-
+$PerlIO::via::Timeout::VERSION = '0.30';
 # ABSTRACT: a PerlIO layer that adds read & write timeout to a handle
 
 require 5.008;
+use Time::HiRes;
 use strict;
 use warnings;
 use Carp;
 use Errno qw(EBADF EINTR ETIMEDOUT);
-use Scalar::Util qw(reftype blessed weaken);
 
 use Exporter 'import'; # gives you Exporter's import() method directly
 
@@ -131,7 +128,7 @@ sub WRITE {
 sub _can_read_write {
     my ($fh, $fd, $timeout, $type) = @_;
     # $type: 0 = read, 1 = write
-    my $initial = time;
+    my $initial = Time::HiRes::time;
     my $pending = $timeout;
     my $nfound;
 
@@ -148,7 +145,7 @@ sub _can_read_write {
         if ($nfound == -1) {
             $! == EINTR
               or croak(qq/select(2): '$!'/);
-            redo if !$timeout || ($pending = $timeout - (time -
+            redo if !$timeout || ($pending = $timeout - (Time::HiRes::time -
             $initial)) > 0;
             $nfound = 0;
         }
@@ -191,19 +188,28 @@ sub timeout_enabled {
     $prop->{timeout_enabled};
 }
 
+
+sub has_timeout_layer {
+    defined (my $fd = _get_fd($_[0]))
+      or return;
+    exists $fd2prop{$fd};
+}
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PerlIO::via::Timeout - a PerlIO layer that adds read & write timeout to a handle
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -230,7 +236,7 @@ The timeout is implemented by using C<<select>> on the handle before
 reading/writing.
 
 B<WARNING> the handle won't timeout if you use C<sysread> or C<syswrite> on it,
-because these functions works at a lower level. Hower if you're trying to
+because these functions works at a lower level. However if you're trying to
 implement a timeout for a socket, see L<IO::Socket::Timeout> that implements
 exactly that.
 
@@ -248,9 +254,9 @@ Getter / setter of the read timeout value.
 =head2 write_timeout
 
   # set a write timeout of 2.5 seconds
-  timeout_layer($fh)->write_timeout(2.5);
+  write_timeout($fh, 2.5);
   # get the current write timeout
-  my $secs = timeout_layer($fh)->write_timeout();
+  my $secs = write_timeout($fh);
 
 Getter / setter of the write timeout value.
 
@@ -262,7 +268,7 @@ Equivalent to setting timeout_enabled to 1
 
 =head2 disable_timeout
 
-  timeout_layer($fh)->disable_timeout();
+  disable_timeout($fh);
 
 Equivalent to setting timeout_enabled to 0
 
@@ -277,6 +283,15 @@ Equivalent to setting timeout_enabled to 0
 
 Getter / setter of the timeout enabled flag.
 
+=head2 has_timeout_layer
+
+  if (has_timeout_layer($fh)) {
+    # set a write timeout of 2.5 seconds
+    write_timeout($fh, 2.5);
+  }
+
+Returns wether the given filehandle is managed by PerlIO::via::Timeout.
+
 =head1 SEE ALSO
 
 =over
